# Changelog

## 0.39.0 (2026-04-03)

Full Changelog: [v0.38.0...v0.39.0](https://github.com/CaseMark/casedev-python/compare/v0.38.0...v0.39.0)

### Features

* **api:** api update ([f6621cd](https://github.com/CaseMark/casedev-python/commit/f6621cdfe2e6fd6e57530067fff798350146913b))

## 0.38.0 (2026-04-01)

Full Changelog: [v0.37.2...v0.38.0](https://github.com/CaseMark/casedev-python/compare/v0.37.2...v0.38.0)

### Features

* **api:** api update ([d861ea7](https://github.com/CaseMark/casedev-python/commit/d861ea7dc9616d28470efaaffb7e71454f5c184f))

## 0.37.2 (2026-04-01)

Full Changelog: [v0.37.1...v0.37.2](https://github.com/CaseMark/casedev-python/compare/v0.37.1...v0.37.2)

### Chores

* **tests:** bump steady to v0.20.2 ([069ff69](https://github.com/CaseMark/casedev-python/commit/069ff69df2dbd87853a7629c0cd0774794fd2ecf))

## 0.37.1 (2026-04-01)

Full Changelog: [v0.37.0...v0.37.1](https://github.com/CaseMark/casedev-python/compare/v0.37.0...v0.37.1)

### Chores

* **tests:** bump steady to v0.20.1 ([9c29b5a](https://github.com/CaseMark/casedev-python/commit/9c29b5aa992d0e41cbd3f9469755351870796e7d))

## 0.37.0 (2026-03-31)

Full Changelog: [v0.36.0...v0.37.0](https://github.com/CaseMark/casedev-python/compare/v0.36.0...v0.37.0)

### Features

* **api:** api update ([17472a1](https://github.com/CaseMark/casedev-python/commit/17472a12bdc779ef8636cde07845a271c5afdf51))

## 0.36.0 (2026-03-31)

Full Changelog: [v0.35.0...v0.36.0](https://github.com/CaseMark/casedev-python/compare/v0.35.0...v0.36.0)

### Features

* **api:** api update ([b89e823](https://github.com/CaseMark/casedev-python/commit/b89e82384cb54fc9ad2111e34112166947f60595))

## 0.35.0 (2026-03-30)

Full Changelog: [v0.34.0...v0.35.0](https://github.com/CaseMark/casedev-python/compare/v0.34.0...v0.35.0)

### Features

* **api:** api update ([a7325fc](https://github.com/CaseMark/casedev-python/commit/a7325fcde36bd2f33f7ced3256c974b29673120e))

## 0.34.0 (2026-03-28)

Full Changelog: [v0.33.0...v0.34.0](https://github.com/CaseMark/casedev-python/compare/v0.33.0...v0.34.0)

### Features

* **api:** api update ([10771a0](https://github.com/CaseMark/casedev-python/commit/10771a0be0d077177b1eee10789d03c1d8ef89f4))

## 0.33.0 (2026-03-27)

Full Changelog: [v0.32.0...v0.33.0](https://github.com/CaseMark/casedev-python/compare/v0.32.0...v0.33.0)

### Features

* **api:** api update ([7b40630](https://github.com/CaseMark/casedev-python/commit/7b406308b1dc209df2ff3b4b999430d40e492ee5))

## 0.32.0 (2026-03-27)

Full Changelog: [v0.31.6...v0.32.0](https://github.com/CaseMark/casedev-python/compare/v0.31.6...v0.32.0)

### Features

* **internal:** implement indices array format for query and form serialization ([a34a2e6](https://github.com/CaseMark/casedev-python/commit/a34a2e69e7254d9a83fe951210171d9e92cc5345))

## 0.31.6 (2026-03-25)

Full Changelog: [v0.31.5...v0.31.6](https://github.com/CaseMark/casedev-python/compare/v0.31.5...v0.31.6)

### Chores

* **ci:** skip lint on metadata-only changes ([4589ef7](https://github.com/CaseMark/casedev-python/commit/4589ef73f23e643936968ead8d9c38eda4380543))
* **tests:** bump steady to v0.19.7 ([8f641c8](https://github.com/CaseMark/casedev-python/commit/8f641c8173561f40afe5ae161835398a49fad36a))

## 0.31.5 (2026-03-24)

Full Changelog: [v0.31.4...v0.31.5](https://github.com/CaseMark/casedev-python/compare/v0.31.4...v0.31.5)

### Chores

* **tests:** bump steady to v0.19.6 ([0a5b615](https://github.com/CaseMark/casedev-python/commit/0a5b615b397db25ccce8a8f5737d25fa61fd77ab))

## 0.31.4 (2026-03-24)

Full Changelog: [v0.31.3...v0.31.4](https://github.com/CaseMark/casedev-python/compare/v0.31.3...v0.31.4)

### Chores

* **internal:** update gitignore ([9cf68da](https://github.com/CaseMark/casedev-python/commit/9cf68dafcb82c3d1227af09deb8ccfe2ca1d4cc1))

## 0.31.3 (2026-03-21)

Full Changelog: [v0.31.2...v0.31.3](https://github.com/CaseMark/casedev-python/compare/v0.31.2...v0.31.3)

### Chores

* **tests:** bump steady to v0.19.5 ([c0fc1ac](https://github.com/CaseMark/casedev-python/commit/c0fc1acfb1798937a85bef243f7cc4ed7b9b702d))

## 0.31.2 (2026-03-21)

Full Changelog: [v0.31.1...v0.31.2](https://github.com/CaseMark/casedev-python/compare/v0.31.1...v0.31.2)

### Chores

* **tests:** bump steady to v0.19.4 ([d547989](https://github.com/CaseMark/casedev-python/commit/d5479891676c6cf0fe90a35d37e663fd3d6ce487))

## 0.31.1 (2026-03-20)

Full Changelog: [v0.31.0...v0.31.1](https://github.com/CaseMark/casedev-python/compare/v0.31.0...v0.31.1)

### Bug Fixes

* sanitize endpoint path params ([937d2a8](https://github.com/CaseMark/casedev-python/commit/937d2a837a60646e18e6658ff4b45de4ce3309a9))


### Refactors

* **tests:** switch from prism to steady ([d29c049](https://github.com/CaseMark/casedev-python/commit/d29c04986bdc46b611748786baa534739425e612))

## 0.31.0 (2026-03-18)

Full Changelog: [v0.30.0...v0.31.0](https://github.com/CaseMark/casedev-python/compare/v0.30.0...v0.31.0)

### Features

* **api:** api update ([4b9411e](https://github.com/CaseMark/casedev-python/commit/4b9411e297ef213db42962874c2b0b5b847838a6))
* **api:** api update ([072cedf](https://github.com/CaseMark/casedev-python/commit/072cedf9d774cba52e19e4b2275a388d1cd5a7d2))
* **api:** api update ([8c08695](https://github.com/CaseMark/casedev-python/commit/8c08695f4b0c98f06f0a08ee139a2be78cc8d770))
* **api:** api update ([f4ede36](https://github.com/CaseMark/casedev-python/commit/f4ede36689cbbb4fbf7af3d6ea17cbf1bbfd0b61))
* **api:** api update ([bbc1958](https://github.com/CaseMark/casedev-python/commit/bbc19583a48d689f36d3b73331df31100a6bff51))
* **api:** api update ([79d80eb](https://github.com/CaseMark/casedev-python/commit/79d80ebe4fe7c24aefac21b3952b7c453a9c0fdc))
* **api:** api update ([87a0fa7](https://github.com/CaseMark/casedev-python/commit/87a0fa7a1d964d12ff95e28d5680d42459f505a9))
* **api:** api update ([ae40ade](https://github.com/CaseMark/casedev-python/commit/ae40ade8c0759de6f9089fd86d220aa7453f0895))
* **api:** api update ([188c163](https://github.com/CaseMark/casedev-python/commit/188c1634025666242ae5998e99bc7776afa05b1e))
* **api:** api update ([c5a54e6](https://github.com/CaseMark/casedev-python/commit/c5a54e6759c5392c49fb7b8100a7971058c98900))
* **api:** api update ([6f27ae6](https://github.com/CaseMark/casedev-python/commit/6f27ae6f5665f97b489b886acf992bf8d1db3f61))
* **api:** api update ([77b06ab](https://github.com/CaseMark/casedev-python/commit/77b06abdb2d7d0ab0098a2e822c6ca7e073664f7))
* **api:** api update ([77aa31b](https://github.com/CaseMark/casedev-python/commit/77aa31b8549d5d578149ec04cf93f6dee72b7ec4))
* **api:** api update ([05fb516](https://github.com/CaseMark/casedev-python/commit/05fb5164d0e7dd5984663fed45330fe080af86fc))
* **api:** api update ([2960b73](https://github.com/CaseMark/casedev-python/commit/2960b736a990d35a0c4aecf89c7318946619fe30))
* **api:** api update ([485daaa](https://github.com/CaseMark/casedev-python/commit/485daaa2873139395ac554a40b0fa29e974642cd))
* **api:** api update ([3e84faf](https://github.com/CaseMark/casedev-python/commit/3e84fafb3536ed4097d29cf6b691198e4729c3b4))
* **api:** api update ([9e34f8a](https://github.com/CaseMark/casedev-python/commit/9e34f8a5dccba5cdb95c1f95208606a6a4a2f440))
* **api:** api update ([135dc3c](https://github.com/CaseMark/casedev-python/commit/135dc3cd51e46fe958d0065821432194c4879beb))
* **api:** api update ([77773aa](https://github.com/CaseMark/casedev-python/commit/77773aa58e7a5b7296404f1a0cece53c7cbb4d92))
* **api:** api update ([40e0ea7](https://github.com/CaseMark/casedev-python/commit/40e0ea76d287d25604d7f38fb9bea42e6bd6ed30))
* **api:** api update ([c78983e](https://github.com/CaseMark/casedev-python/commit/c78983ef3cca3346dbfd600bd3587fced8ac3104))
* **api:** api update ([02f2b6c](https://github.com/CaseMark/casedev-python/commit/02f2b6c264aa9c775e629951e2048a8690619223))
* **api:** api update ([d972fb9](https://github.com/CaseMark/casedev-python/commit/d972fb973d9472dcd6836294bb7fbc4cabc5885c))
* **api:** api update ([e7ff6af](https://github.com/CaseMark/casedev-python/commit/e7ff6af489dece42b6798c8df1f68f26062882cf))
* **api:** api update ([dac2fef](https://github.com/CaseMark/casedev-python/commit/dac2fef17bc0cea70d0a6e0448091416df778816))
* **api:** api update ([001c8e9](https://github.com/CaseMark/casedev-python/commit/001c8e905cb208739022b59a32757120542e74bc))
* **api:** api update ([a38391d](https://github.com/CaseMark/casedev-python/commit/a38391d62d18cec8a24b36f645e5c520bfa83c48))
* **api:** api update ([bf7f3a0](https://github.com/CaseMark/casedev-python/commit/bf7f3a04d0ebbcfba9be0e2dbafa66523f6ffe4e))
* **api:** api update ([31394a2](https://github.com/CaseMark/casedev-python/commit/31394a2dddf5681cf21881b6647f9d5c767fe681))
* **api:** api update ([42adc10](https://github.com/CaseMark/casedev-python/commit/42adc108a7fbdb8bb08822a95270d4bcd0647ac8))
* **api:** api update ([7680735](https://github.com/CaseMark/casedev-python/commit/768073544334f388580595059eb36392caa5de63))
* **api:** api update ([2d83c1e](https://github.com/CaseMark/casedev-python/commit/2d83c1e1737b17e38589ae70d199026066dd7fb5))
* **api:** api update ([687dbe1](https://github.com/CaseMark/casedev-python/commit/687dbe1cf0c63fc9085265254015dc064087f7d7))
* **api:** api update ([9552466](https://github.com/CaseMark/casedev-python/commit/95524660fc8d6bc6b4afbd3e881bf15e7378cfe0))
* **api:** api update ([e3f5b6b](https://github.com/CaseMark/casedev-python/commit/e3f5b6bcc11924a87716cbb6e99d39e0c0603f74))
* **api:** api update ([ab9ad93](https://github.com/CaseMark/casedev-python/commit/ab9ad9365e44ec36f5ba3cb5c47436bcdcba095e))
* **api:** api update ([92d6d3e](https://github.com/CaseMark/casedev-python/commit/92d6d3e780ef1f21b3d5fb1839be1bb1973bdec9))
* **api:** api update ([c1ae1f0](https://github.com/CaseMark/casedev-python/commit/c1ae1f0f67d01c6131cea0a3cdfdd7b62430e57a))
* **api:** api update ([3da66e8](https://github.com/CaseMark/casedev-python/commit/3da66e8087429a2464cde0e7ccf9f00816c9253f))
* **api:** api update ([daeeb24](https://github.com/CaseMark/casedev-python/commit/daeeb24466300096491bed4ebce78563880364b5))
* **api:** api update ([0809936](https://github.com/CaseMark/casedev-python/commit/0809936b454b3b9c5f7e5c743a8c830f7aa071bb))
* **api:** api update ([7292310](https://github.com/CaseMark/casedev-python/commit/729231070af873c8a63a9a4ecaddf7785e774456))
* **api:** api update ([684d926](https://github.com/CaseMark/casedev-python/commit/684d92629f3c3a202cebfc45f5dd21f7c17b5877))
* **api:** api update ([17fc13d](https://github.com/CaseMark/casedev-python/commit/17fc13d0818e3770b2c786b6fd9c7c06c3b9d25d))
* **api:** api update ([737d1c8](https://github.com/CaseMark/casedev-python/commit/737d1c897994e3a7bbfab340db4c358e4d13d5ca))
* **api:** api update ([3e3e1e1](https://github.com/CaseMark/casedev-python/commit/3e3e1e1ce03245a91567ef6682aa9e0bf4d1aa00))
* **api:** api update ([6071351](https://github.com/CaseMark/casedev-python/commit/60713515ebe6c2fb3c545243e4865ae8b2aa96f4))
* **api:** api update ([8d1fc91](https://github.com/CaseMark/casedev-python/commit/8d1fc919b184800cf5c27b3cb447ea6a6f61dbb2))
* **api:** api update ([1cb2be4](https://github.com/CaseMark/casedev-python/commit/1cb2be4e85317ac44b253093db82e4006e2133e3))
* **api:** api update ([c8f0f13](https://github.com/CaseMark/casedev-python/commit/c8f0f134473037efbfd902d41b4405a40dac28cb))
* **api:** api update ([5b7d521](https://github.com/CaseMark/casedev-python/commit/5b7d521ede56af8932dd19610afcd37df7483c96))
* **api:** api update ([48fbc0d](https://github.com/CaseMark/casedev-python/commit/48fbc0d8e45c8de7d7279a44291bdd9556b3f853))
* **api:** api update ([eb5d48c](https://github.com/CaseMark/casedev-python/commit/eb5d48c07bcc1b14319a4e6fbaf4b45f46b0582b))
* **api:** api update ([f016636](https://github.com/CaseMark/casedev-python/commit/f01663617b152a538b7ca668272be3dfcc3b0dc9))
* **api:** api update ([3966424](https://github.com/CaseMark/casedev-python/commit/3966424bf12ae7bd1c389fb18e85ec27fb784b4c))
* **api:** api update ([bdd8f5b](https://github.com/CaseMark/casedev-python/commit/bdd8f5b481346d6354609b4b09ebae8dbd71a9fc))
* **api:** api update ([8d0cbe9](https://github.com/CaseMark/casedev-python/commit/8d0cbe93ef8fb68e4895b064c7a5483b8d50dc2c))
* **api:** api update ([46a5bca](https://github.com/CaseMark/casedev-python/commit/46a5bcab1b018f33c1c45daf3584678fece36f3c))
* **api:** manual updates ([0857a27](https://github.com/CaseMark/casedev-python/commit/0857a27df9330ed223236f22b4c086146c15d1f8))
* **api:** manual updates ([eeb7830](https://github.com/CaseMark/casedev-python/commit/eeb7830cb058b1ef4be3c6edfefa1a33efe16f0e))
* **api:** manual updates ([7c7022f](https://github.com/CaseMark/casedev-python/commit/7c7022f6e7b5603b8e98f75fe102219f789ff3ba))
* **client:** add custom JSON encoder for extended type support ([34a252e](https://github.com/CaseMark/casedev-python/commit/34a252ea9464e00bd27f8b12fcb027e283c095bd))
* **client:** add support for binary request streaming ([b425d21](https://github.com/CaseMark/casedev-python/commit/b425d2114285d843565d6a0d907e0b3b4817bb91))


### Bug Fixes

* deduplicate CI Slack alerts at workflow level, not PR level ([#41](https://github.com/CaseMark/casedev-python/issues/41)) ([3b5a07b](https://github.com/CaseMark/casedev-python/commit/3b5a07b58dc107b49c5c7581ed8327cbeee8d20b))
* **deps:** bump minimum typing-extensions version ([6256dbc](https://github.com/CaseMark/casedev-python/commit/6256dbcb7233cc39f303c12c71cc0186046cb262))
* ensure streams are always closed ([b30b9ec](https://github.com/CaseMark/casedev-python/commit/b30b9ec808299da7d4bfade2a52b9a5529bf3d9a))
* only alert on CI failure for PRs targeting main ([7ad6c4b](https://github.com/CaseMark/casedev-python/commit/7ad6c4b62772ab94d3ca060d27f587eb7e5f8672))
* only alert Slack on CI failure for main branch ([0941a51](https://github.com/CaseMark/casedev-python/commit/0941a5150ba78f3661915378cfd10f7d2dd059b4))
* prevent duplicate Slack alerts from release-please branches ([5baa9ee](https://github.com/CaseMark/casedev-python/commit/5baa9ee4572bed65b873e4a0e5d7c1e5c0f694f9))
* **pydantic:** do not pass `by_alias` unless set ([b633f75](https://github.com/CaseMark/casedev-python/commit/b633f753d30a73b0571be7af339bfec81e649087))
* resolve CI failures in smoke test integration ([9f166ff](https://github.com/CaseMark/casedev-python/commit/9f166ffdbdbe73ac5092a212070e11350ba3d9ff))
* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([9d591ca](https://github.com/CaseMark/casedev-python/commit/9d591caeb879fcf7a102b18ac1f9889a44df24f7))
* use async_to_httpx_files in patch method ([f388e39](https://github.com/CaseMark/casedev-python/commit/f388e395df9f144a4596066297bfb70259179634))


### Chores

* add missing docstrings ([537e98d](https://github.com/CaseMark/casedev-python/commit/537e98d1b5e2a90bc8d19db502ec7f7dbf1c9a5c))
* **ci:** bump uv version ([e739162](https://github.com/CaseMark/casedev-python/commit/e73916268b1604b6b96e894fa0df2da41608ce57))
* **ci:** skip uploading artifacts on stainless-internal branches ([e1c51bd](https://github.com/CaseMark/casedev-python/commit/e1c51bd809ab2cd38ba613c32f049f3d620c3802))
* **ci:** upgrade `actions/github-script` ([170f959](https://github.com/CaseMark/casedev-python/commit/170f959ccbb0ec0cd16e7d2e8f393825de517b7b))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([714ab77](https://github.com/CaseMark/casedev-python/commit/714ab7768f8895da8e0e6c56ceb506dd946d7e76))
* **docs:** use environment variables for authentication in code snippets ([f57c037](https://github.com/CaseMark/casedev-python/commit/f57c037c435e38d740180acdfa155252f610315e))
* format all `api.md` files ([9b7d49d](https://github.com/CaseMark/casedev-python/commit/9b7d49d466da0c24711a93762a5f2e206f29279c))
* **internal:** add `--fix` argument to lint script ([e458171](https://github.com/CaseMark/casedev-python/commit/e458171364ac59b0c574f981ce91d7bae3e08dad))
* **internal:** add missing files argument to base client ([3b24a52](https://github.com/CaseMark/casedev-python/commit/3b24a523d6923af76786b46cbff13530de45a269))
* **internal:** add request options to SSE classes ([c06aa38](https://github.com/CaseMark/casedev-python/commit/c06aa386cdaa7d2aa51eaa088525c61e959844c4))
* **internal:** bump dependencies ([7e338b2](https://github.com/CaseMark/casedev-python/commit/7e338b2495daac85e7c0a0205000e19f0b81a875))
* **internal:** codegen related update ([4fccd08](https://github.com/CaseMark/casedev-python/commit/4fccd0875f8f5a90b640f536548200c6c22f66eb))
* **internal:** fix lint error on Python 3.14 ([3b5d6dc](https://github.com/CaseMark/casedev-python/commit/3b5d6dc771f8933dcbdd7cc7645139b5c224c547))
* **internal:** make `test_proxy_environment_variables` more resilient ([926dcd4](https://github.com/CaseMark/casedev-python/commit/926dcd48c22e1cf94f3894ed365df6898cb27c59))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([574334a](https://github.com/CaseMark/casedev-python/commit/574334a89b19baa8fcbb72100c2fc033f2a3c80c))
* **internal:** remove mock server code ([084425e](https://github.com/CaseMark/casedev-python/commit/084425e59cb125778ca0a37194c49a10124eb98c))
* **internal:** tweak CI branches ([cbe4126](https://github.com/CaseMark/casedev-python/commit/cbe4126732a0d975e1b4e5d02c0c599e0377e2c9))
* **internal:** update `actions/checkout` version ([79aaafc](https://github.com/CaseMark/casedev-python/commit/79aaafcc099c50403f9f2390919d7c52a990d1d3))
* replace PR open Slack alert with CI failure alert ([ddb4311](https://github.com/CaseMark/casedev-python/commit/ddb4311f3e9dbd837e147278e74360c53edfc39f))
* speedup initial import ([0b1a4ce](https://github.com/CaseMark/casedev-python/commit/0b1a4cef391a23c08f5ef68e2a9a6e2af165b104))
* **test:** do not count install time for mock server timeout ([8bdc678](https://github.com/CaseMark/casedev-python/commit/8bdc67826e5fcff5d67eaa3a493b2be405a58fdb))
* update lockfile ([56cba77](https://github.com/CaseMark/casedev-python/commit/56cba77d5c25b33a5464120c58e648a44921b43c))
* update mock server docs ([619f816](https://github.com/CaseMark/casedev-python/commit/619f8166b5b650a4ac561276577de12ced62daeb))
* update SDK settings ([ced48fc](https://github.com/CaseMark/casedev-python/commit/ced48fc84cb98d79e3eeed74802f473dcfecb0da))
* update SDK settings ([48c16fc](https://github.com/CaseMark/casedev-python/commit/48c16fc44133177a044b13de279b7dc1d680fc1a))
* update SDK settings ([0fb22b3](https://github.com/CaseMark/casedev-python/commit/0fb22b30b2bf11f50b8c7a23e020c3e51878f817))


### Styles

* fix ruff isort import formatting in smoke tests ([e80a3f3](https://github.com/CaseMark/casedev-python/commit/e80a3f35b28539a307ccf6be344e862cfb18679e))


### Refactors

* **internal:** switch from rye to uv ([7e5d72f](https://github.com/CaseMark/casedev-python/commit/7e5d72f6d2bcc8927840bf87986233ff83738580))
* **types:** use `extra_items` from PEP 728 ([4c16824](https://github.com/CaseMark/casedev-python/commit/4c168248947f9b55e2017d86cc4cadd95e9b1519))

## 0.30.0 (2026-03-18)

Full Changelog: [v0.29.0...v0.30.0](https://github.com/CaseMark/casedev-python/compare/v0.29.0...v0.30.0)

### Features

* **api:** api update ([4b9411e](https://github.com/CaseMark/casedev-python/commit/4b9411e297ef213db42962874c2b0b5b847838a6))

## 0.29.0 (2026-03-17)

Full Changelog: [v0.28.4...v0.29.0](https://github.com/CaseMark/casedev-python/compare/v0.28.4...v0.29.0)

### Features

* **api:** api update ([072cedf](https://github.com/CaseMark/casedev-python/commit/072cedf9d774cba52e19e4b2275a388d1cd5a7d2))

## 0.28.4 (2026-03-17)

Full Changelog: [v0.28.3...v0.28.4](https://github.com/CaseMark/casedev-python/compare/v0.28.3...v0.28.4)

## 0.28.3 (2026-03-17)

Full Changelog: [v0.28.2...v0.28.3](https://github.com/CaseMark/casedev-python/compare/v0.28.2...v0.28.3)

### Chores

* **internal:** tweak CI branches ([cbe4126](https://github.com/CaseMark/casedev-python/commit/cbe4126732a0d975e1b4e5d02c0c599e0377e2c9))

## 0.28.2 (2026-03-17)

Full Changelog: [v0.28.1...v0.28.2](https://github.com/CaseMark/casedev-python/compare/v0.28.1...v0.28.2)

### Bug Fixes

* **deps:** bump minimum typing-extensions version ([6256dbc](https://github.com/CaseMark/casedev-python/commit/6256dbcb7233cc39f303c12c71cc0186046cb262))

## 0.28.1 (2026-03-17)

Full Changelog: [v0.28.0...v0.28.1](https://github.com/CaseMark/casedev-python/compare/v0.28.0...v0.28.1)

### Bug Fixes

* **pydantic:** do not pass `by_alias` unless set ([b633f75](https://github.com/CaseMark/casedev-python/commit/b633f753d30a73b0571be7af339bfec81e649087))

## 0.28.0 (2026-03-16)

Full Changelog: [v0.27.0...v0.28.0](https://github.com/CaseMark/casedev-python/compare/v0.27.0...v0.28.0)

### Features

* **api:** api update ([8c08695](https://github.com/CaseMark/casedev-python/commit/8c08695f4b0c98f06f0a08ee139a2be78cc8d770))

## 0.27.0 (2026-03-13)

Full Changelog: [v0.26.0...v0.27.0](https://github.com/CaseMark/casedev-python/compare/v0.26.0...v0.27.0)

### Features

* **api:** api update ([f4ede36](https://github.com/CaseMark/casedev-python/commit/f4ede36689cbbb4fbf7af3d6ea17cbf1bbfd0b61))

## 0.26.0 (2026-03-13)

Full Changelog: [v0.25.0...v0.26.0](https://github.com/CaseMark/casedev-python/compare/v0.25.0...v0.26.0)

### Features

* **api:** api update ([bbc1958](https://github.com/CaseMark/casedev-python/commit/bbc19583a48d689f36d3b73331df31100a6bff51))

## 0.25.0 (2026-03-12)

Full Changelog: [v0.24.0...v0.25.0](https://github.com/CaseMark/casedev-python/compare/v0.24.0...v0.25.0)

### Features

* **api:** api update ([79d80eb](https://github.com/CaseMark/casedev-python/commit/79d80ebe4fe7c24aefac21b3952b7c453a9c0fdc))

## 0.24.0 (2026-03-11)

Full Changelog: [v0.23.0...v0.24.0](https://github.com/CaseMark/casedev-python/compare/v0.23.0...v0.24.0)

### Features

* **api:** api update ([87a0fa7](https://github.com/CaseMark/casedev-python/commit/87a0fa7a1d964d12ff95e28d5680d42459f505a9))

## 0.23.0 (2026-03-11)

Full Changelog: [v0.22.0...v0.23.0](https://github.com/CaseMark/casedev-python/compare/v0.22.0...v0.23.0)

### Features

* **api:** api update ([ae40ade](https://github.com/CaseMark/casedev-python/commit/ae40ade8c0759de6f9089fd86d220aa7453f0895))

## 0.22.0 (2026-03-09)

Full Changelog: [v0.21.3...v0.22.0](https://github.com/CaseMark/casedev-python/compare/v0.21.3...v0.22.0)

### Features

* **api:** api update ([188c163](https://github.com/CaseMark/casedev-python/commit/188c1634025666242ae5998e99bc7776afa05b1e))

## 0.21.3 (2026-03-07)

Full Changelog: [v0.21.2...v0.21.3](https://github.com/CaseMark/casedev-python/compare/v0.21.2...v0.21.3)

### Chores

* **ci:** skip uploading artifacts on stainless-internal branches ([e1c51bd](https://github.com/CaseMark/casedev-python/commit/e1c51bd809ab2cd38ba613c32f049f3d620c3802))

## 0.21.2 (2026-03-07)

Full Changelog: [v0.21.1...v0.21.2](https://github.com/CaseMark/casedev-python/compare/v0.21.1...v0.21.2)

### Chores

* **test:** do not count install time for mock server timeout ([8bdc678](https://github.com/CaseMark/casedev-python/commit/8bdc67826e5fcff5d67eaa3a493b2be405a58fdb))

## 0.21.1 (2026-03-07)

Full Changelog: [v0.21.0...v0.21.1](https://github.com/CaseMark/casedev-python/compare/v0.21.0...v0.21.1)

### Refactors

* **types:** use `extra_items` from PEP 728 ([4c16824](https://github.com/CaseMark/casedev-python/commit/4c168248947f9b55e2017d86cc4cadd95e9b1519))

## 0.21.0 (2026-03-06)

Full Changelog: [v0.20.0...v0.21.0](https://github.com/CaseMark/casedev-python/compare/v0.20.0...v0.21.0)

### Features

* **api:** api update ([c5a54e6](https://github.com/CaseMark/casedev-python/commit/c5a54e6759c5392c49fb7b8100a7971058c98900))
* **api:** api update ([6f27ae6](https://github.com/CaseMark/casedev-python/commit/6f27ae6f5665f97b489b886acf992bf8d1db3f61))
* **api:** api update ([77b06ab](https://github.com/CaseMark/casedev-python/commit/77b06abdb2d7d0ab0098a2e822c6ca7e073664f7))
* **api:** api update ([77aa31b](https://github.com/CaseMark/casedev-python/commit/77aa31b8549d5d578149ec04cf93f6dee72b7ec4))
* **api:** api update ([05fb516](https://github.com/CaseMark/casedev-python/commit/05fb5164d0e7dd5984663fed45330fe080af86fc))
* **api:** api update ([2960b73](https://github.com/CaseMark/casedev-python/commit/2960b736a990d35a0c4aecf89c7318946619fe30))
* **api:** api update ([485daaa](https://github.com/CaseMark/casedev-python/commit/485daaa2873139395ac554a40b0fa29e974642cd))
* **api:** api update ([3e84faf](https://github.com/CaseMark/casedev-python/commit/3e84fafb3536ed4097d29cf6b691198e4729c3b4))
* **api:** api update ([9e34f8a](https://github.com/CaseMark/casedev-python/commit/9e34f8a5dccba5cdb95c1f95208606a6a4a2f440))
* **api:** api update ([135dc3c](https://github.com/CaseMark/casedev-python/commit/135dc3cd51e46fe958d0065821432194c4879beb))
* **api:** api update ([77773aa](https://github.com/CaseMark/casedev-python/commit/77773aa58e7a5b7296404f1a0cece53c7cbb4d92))
* **api:** api update ([40e0ea7](https://github.com/CaseMark/casedev-python/commit/40e0ea76d287d25604d7f38fb9bea42e6bd6ed30))
* **api:** api update ([c78983e](https://github.com/CaseMark/casedev-python/commit/c78983ef3cca3346dbfd600bd3587fced8ac3104))
* **api:** api update ([02f2b6c](https://github.com/CaseMark/casedev-python/commit/02f2b6c264aa9c775e629951e2048a8690619223))
* **api:** api update ([d972fb9](https://github.com/CaseMark/casedev-python/commit/d972fb973d9472dcd6836294bb7fbc4cabc5885c))
* **api:** api update ([e7ff6af](https://github.com/CaseMark/casedev-python/commit/e7ff6af489dece42b6798c8df1f68f26062882cf))
* **api:** api update ([dac2fef](https://github.com/CaseMark/casedev-python/commit/dac2fef17bc0cea70d0a6e0448091416df778816))
* **api:** api update ([001c8e9](https://github.com/CaseMark/casedev-python/commit/001c8e905cb208739022b59a32757120542e74bc))
* **api:** api update ([a38391d](https://github.com/CaseMark/casedev-python/commit/a38391d62d18cec8a24b36f645e5c520bfa83c48))
* **api:** api update ([bf7f3a0](https://github.com/CaseMark/casedev-python/commit/bf7f3a04d0ebbcfba9be0e2dbafa66523f6ffe4e))
* **api:** api update ([31394a2](https://github.com/CaseMark/casedev-python/commit/31394a2dddf5681cf21881b6647f9d5c767fe681))
* **api:** api update ([42adc10](https://github.com/CaseMark/casedev-python/commit/42adc108a7fbdb8bb08822a95270d4bcd0647ac8))
* **api:** api update ([7680735](https://github.com/CaseMark/casedev-python/commit/768073544334f388580595059eb36392caa5de63))
* **api:** api update ([2d83c1e](https://github.com/CaseMark/casedev-python/commit/2d83c1e1737b17e38589ae70d199026066dd7fb5))
* **api:** api update ([687dbe1](https://github.com/CaseMark/casedev-python/commit/687dbe1cf0c63fc9085265254015dc064087f7d7))
* **api:** api update ([9552466](https://github.com/CaseMark/casedev-python/commit/95524660fc8d6bc6b4afbd3e881bf15e7378cfe0))
* **api:** api update ([e3f5b6b](https://github.com/CaseMark/casedev-python/commit/e3f5b6bcc11924a87716cbb6e99d39e0c0603f74))
* **api:** api update ([ab9ad93](https://github.com/CaseMark/casedev-python/commit/ab9ad9365e44ec36f5ba3cb5c47436bcdcba095e))
* **api:** api update ([92d6d3e](https://github.com/CaseMark/casedev-python/commit/92d6d3e780ef1f21b3d5fb1839be1bb1973bdec9))
* **api:** api update ([c1ae1f0](https://github.com/CaseMark/casedev-python/commit/c1ae1f0f67d01c6131cea0a3cdfdd7b62430e57a))
* **api:** api update ([3da66e8](https://github.com/CaseMark/casedev-python/commit/3da66e8087429a2464cde0e7ccf9f00816c9253f))
* **api:** api update ([daeeb24](https://github.com/CaseMark/casedev-python/commit/daeeb24466300096491bed4ebce78563880364b5))
* **api:** api update ([0809936](https://github.com/CaseMark/casedev-python/commit/0809936b454b3b9c5f7e5c743a8c830f7aa071bb))
* **api:** api update ([7292310](https://github.com/CaseMark/casedev-python/commit/729231070af873c8a63a9a4ecaddf7785e774456))
* **api:** api update ([684d926](https://github.com/CaseMark/casedev-python/commit/684d92629f3c3a202cebfc45f5dd21f7c17b5877))
* **api:** api update ([17fc13d](https://github.com/CaseMark/casedev-python/commit/17fc13d0818e3770b2c786b6fd9c7c06c3b9d25d))
* **api:** api update ([737d1c8](https://github.com/CaseMark/casedev-python/commit/737d1c897994e3a7bbfab340db4c358e4d13d5ca))
* **api:** api update ([3e3e1e1](https://github.com/CaseMark/casedev-python/commit/3e3e1e1ce03245a91567ef6682aa9e0bf4d1aa00))
* **api:** api update ([6071351](https://github.com/CaseMark/casedev-python/commit/60713515ebe6c2fb3c545243e4865ae8b2aa96f4))
* **api:** api update ([8d1fc91](https://github.com/CaseMark/casedev-python/commit/8d1fc919b184800cf5c27b3cb447ea6a6f61dbb2))
* **api:** api update ([1cb2be4](https://github.com/CaseMark/casedev-python/commit/1cb2be4e85317ac44b253093db82e4006e2133e3))
* **api:** api update ([c8f0f13](https://github.com/CaseMark/casedev-python/commit/c8f0f134473037efbfd902d41b4405a40dac28cb))
* **api:** api update ([5b7d521](https://github.com/CaseMark/casedev-python/commit/5b7d521ede56af8932dd19610afcd37df7483c96))
* **api:** api update ([48fbc0d](https://github.com/CaseMark/casedev-python/commit/48fbc0d8e45c8de7d7279a44291bdd9556b3f853))
* **api:** api update ([eb5d48c](https://github.com/CaseMark/casedev-python/commit/eb5d48c07bcc1b14319a4e6fbaf4b45f46b0582b))
* **api:** api update ([f016636](https://github.com/CaseMark/casedev-python/commit/f01663617b152a538b7ca668272be3dfcc3b0dc9))
* **api:** api update ([3966424](https://github.com/CaseMark/casedev-python/commit/3966424bf12ae7bd1c389fb18e85ec27fb784b4c))
* **api:** api update ([bdd8f5b](https://github.com/CaseMark/casedev-python/commit/bdd8f5b481346d6354609b4b09ebae8dbd71a9fc))
* **api:** api update ([8d0cbe9](https://github.com/CaseMark/casedev-python/commit/8d0cbe93ef8fb68e4895b064c7a5483b8d50dc2c))
* **api:** api update ([46a5bca](https://github.com/CaseMark/casedev-python/commit/46a5bcab1b018f33c1c45daf3584678fece36f3c))
* **api:** manual updates ([0857a27](https://github.com/CaseMark/casedev-python/commit/0857a27df9330ed223236f22b4c086146c15d1f8))
* **api:** manual updates ([eeb7830](https://github.com/CaseMark/casedev-python/commit/eeb7830cb058b1ef4be3c6edfefa1a33efe16f0e))
* **api:** manual updates ([7c7022f](https://github.com/CaseMark/casedev-python/commit/7c7022f6e7b5603b8e98f75fe102219f789ff3ba))
* **client:** add custom JSON encoder for extended type support ([34a252e](https://github.com/CaseMark/casedev-python/commit/34a252ea9464e00bd27f8b12fcb027e283c095bd))
* **client:** add support for binary request streaming ([b425d21](https://github.com/CaseMark/casedev-python/commit/b425d2114285d843565d6a0d907e0b3b4817bb91))


### Bug Fixes

* deduplicate CI Slack alerts at workflow level, not PR level ([#41](https://github.com/CaseMark/casedev-python/issues/41)) ([3b5a07b](https://github.com/CaseMark/casedev-python/commit/3b5a07b58dc107b49c5c7581ed8327cbeee8d20b))
* ensure streams are always closed ([b30b9ec](https://github.com/CaseMark/casedev-python/commit/b30b9ec808299da7d4bfade2a52b9a5529bf3d9a))
* only alert on CI failure for PRs targeting main ([7ad6c4b](https://github.com/CaseMark/casedev-python/commit/7ad6c4b62772ab94d3ca060d27f587eb7e5f8672))
* only alert Slack on CI failure for main branch ([0941a51](https://github.com/CaseMark/casedev-python/commit/0941a5150ba78f3661915378cfd10f7d2dd059b4))
* prevent duplicate Slack alerts from release-please branches ([5baa9ee](https://github.com/CaseMark/casedev-python/commit/5baa9ee4572bed65b873e4a0e5d7c1e5c0f694f9))
* resolve CI failures in smoke test integration ([9f166ff](https://github.com/CaseMark/casedev-python/commit/9f166ffdbdbe73ac5092a212070e11350ba3d9ff))
* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([9d591ca](https://github.com/CaseMark/casedev-python/commit/9d591caeb879fcf7a102b18ac1f9889a44df24f7))
* use async_to_httpx_files in patch method ([f388e39](https://github.com/CaseMark/casedev-python/commit/f388e395df9f144a4596066297bfb70259179634))


### Chores

* add missing docstrings ([537e98d](https://github.com/CaseMark/casedev-python/commit/537e98d1b5e2a90bc8d19db502ec7f7dbf1c9a5c))
* **ci:** bump uv version ([e739162](https://github.com/CaseMark/casedev-python/commit/e73916268b1604b6b96e894fa0df2da41608ce57))
* **ci:** upgrade `actions/github-script` ([170f959](https://github.com/CaseMark/casedev-python/commit/170f959ccbb0ec0cd16e7d2e8f393825de517b7b))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([714ab77](https://github.com/CaseMark/casedev-python/commit/714ab7768f8895da8e0e6c56ceb506dd946d7e76))
* **docs:** use environment variables for authentication in code snippets ([f57c037](https://github.com/CaseMark/casedev-python/commit/f57c037c435e38d740180acdfa155252f610315e))
* format all `api.md` files ([9b7d49d](https://github.com/CaseMark/casedev-python/commit/9b7d49d466da0c24711a93762a5f2e206f29279c))
* **internal:** add `--fix` argument to lint script ([e458171](https://github.com/CaseMark/casedev-python/commit/e458171364ac59b0c574f981ce91d7bae3e08dad))
* **internal:** add missing files argument to base client ([3b24a52](https://github.com/CaseMark/casedev-python/commit/3b24a523d6923af76786b46cbff13530de45a269))
* **internal:** add request options to SSE classes ([c06aa38](https://github.com/CaseMark/casedev-python/commit/c06aa386cdaa7d2aa51eaa088525c61e959844c4))
* **internal:** bump dependencies ([7e338b2](https://github.com/CaseMark/casedev-python/commit/7e338b2495daac85e7c0a0205000e19f0b81a875))
* **internal:** codegen related update ([4fccd08](https://github.com/CaseMark/casedev-python/commit/4fccd0875f8f5a90b640f536548200c6c22f66eb))
* **internal:** fix lint error on Python 3.14 ([3b5d6dc](https://github.com/CaseMark/casedev-python/commit/3b5d6dc771f8933dcbdd7cc7645139b5c224c547))
* **internal:** make `test_proxy_environment_variables` more resilient ([926dcd4](https://github.com/CaseMark/casedev-python/commit/926dcd48c22e1cf94f3894ed365df6898cb27c59))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([574334a](https://github.com/CaseMark/casedev-python/commit/574334a89b19baa8fcbb72100c2fc033f2a3c80c))
* **internal:** remove mock server code ([084425e](https://github.com/CaseMark/casedev-python/commit/084425e59cb125778ca0a37194c49a10124eb98c))
* **internal:** update `actions/checkout` version ([79aaafc](https://github.com/CaseMark/casedev-python/commit/79aaafcc099c50403f9f2390919d7c52a990d1d3))
* replace PR open Slack alert with CI failure alert ([ddb4311](https://github.com/CaseMark/casedev-python/commit/ddb4311f3e9dbd837e147278e74360c53edfc39f))
* speedup initial import ([0b1a4ce](https://github.com/CaseMark/casedev-python/commit/0b1a4cef391a23c08f5ef68e2a9a6e2af165b104))
* update lockfile ([56cba77](https://github.com/CaseMark/casedev-python/commit/56cba77d5c25b33a5464120c58e648a44921b43c))
* update mock server docs ([619f816](https://github.com/CaseMark/casedev-python/commit/619f8166b5b650a4ac561276577de12ced62daeb))
* update SDK settings ([ced48fc](https://github.com/CaseMark/casedev-python/commit/ced48fc84cb98d79e3eeed74802f473dcfecb0da))
* update SDK settings ([48c16fc](https://github.com/CaseMark/casedev-python/commit/48c16fc44133177a044b13de279b7dc1d680fc1a))
* update SDK settings ([0fb22b3](https://github.com/CaseMark/casedev-python/commit/0fb22b30b2bf11f50b8c7a23e020c3e51878f817))


### Styles

* fix ruff isort import formatting in smoke tests ([e80a3f3](https://github.com/CaseMark/casedev-python/commit/e80a3f35b28539a307ccf6be344e862cfb18679e))


### Refactors

* **internal:** switch from rye to uv ([7e5d72f](https://github.com/CaseMark/casedev-python/commit/7e5d72f6d2bcc8927840bf87986233ff83738580))

## 0.20.0 (2026-03-06)

Full Changelog: [v0.19.0...v0.20.0](https://github.com/CaseMark/casedev-python/compare/v0.19.0...v0.20.0)

### Features

* **api:** api update ([c5a54e6](https://github.com/CaseMark/casedev-python/commit/c5a54e6759c5392c49fb7b8100a7971058c98900))

## 0.19.0 (2026-03-06)

Full Changelog: [v0.18.0...v0.19.0](https://github.com/CaseMark/casedev-python/compare/v0.18.0...v0.19.0)

### Features

* **api:** api update ([6f27ae6](https://github.com/CaseMark/casedev-python/commit/6f27ae6f5665f97b489b886acf992bf8d1db3f61))

## 0.18.0 (2026-03-05)

Full Changelog: [v0.17.0...v0.18.0](https://github.com/CaseMark/casedev-python/compare/v0.17.0...v0.18.0)

### Features

* **api:** api update ([77b06ab](https://github.com/CaseMark/casedev-python/commit/77b06abdb2d7d0ab0098a2e822c6ca7e073664f7))

## 0.17.0 (2026-03-05)

Full Changelog: [v0.16.0...v0.17.0](https://github.com/CaseMark/casedev-python/compare/v0.16.0...v0.17.0)

### Features

* **api:** api update ([77aa31b](https://github.com/CaseMark/casedev-python/commit/77aa31b8549d5d578149ec04cf93f6dee72b7ec4))

## 0.16.0 (2026-03-04)

Full Changelog: [v0.15.1...v0.16.0](https://github.com/CaseMark/casedev-python/compare/v0.15.1...v0.16.0)

### Features

* **api:** api update ([05fb516](https://github.com/CaseMark/casedev-python/commit/05fb5164d0e7dd5984663fed45330fe080af86fc))

## 0.15.1 (2026-03-04)

Full Changelog: [v0.15.0...v0.15.1](https://github.com/CaseMark/casedev-python/compare/v0.15.0...v0.15.1)

### Chores

* **internal:** codegen related update ([4fccd08](https://github.com/CaseMark/casedev-python/commit/4fccd0875f8f5a90b640f536548200c6c22f66eb))

## 0.15.0 (2026-03-03)

Full Changelog: [v0.14.1...v0.15.0](https://github.com/CaseMark/casedev-python/compare/v0.14.1...v0.15.0)

### Features

* **api:** api update ([2960b73](https://github.com/CaseMark/casedev-python/commit/2960b736a990d35a0c4aecf89c7318946619fe30))

## 0.14.1 (2026-03-03)

Full Changelog: [v0.14.0...v0.14.1](https://github.com/CaseMark/casedev-python/compare/v0.14.0...v0.14.1)

### Bug Fixes

* deduplicate CI Slack alerts at workflow level, not PR level ([#41](https://github.com/CaseMark/casedev-python/issues/41)) ([3b5a07b](https://github.com/CaseMark/casedev-python/commit/3b5a07b58dc107b49c5c7581ed8327cbeee8d20b))

## 0.14.0 (2026-03-03)

Full Changelog: [v0.13.1...v0.14.0](https://github.com/CaseMark/casedev-python/compare/v0.13.1...v0.14.0)

### Features

* **api:** api update ([485daaa](https://github.com/CaseMark/casedev-python/commit/485daaa2873139395ac554a40b0fa29e974642cd))

## 0.13.1 (2026-02-27)

Full Changelog: [v0.13.0...v0.13.1](https://github.com/CaseMark/casedev-python/compare/v0.13.0...v0.13.1)

### Chores

* **ci:** bump uv version ([e739162](https://github.com/CaseMark/casedev-python/commit/e73916268b1604b6b96e894fa0df2da41608ce57))

## 0.13.0 (2026-02-26)

Full Changelog: [v0.12.6...v0.13.0](https://github.com/CaseMark/casedev-python/compare/v0.12.6...v0.13.0)

### Features

* **api:** api update ([3e84faf](https://github.com/CaseMark/casedev-python/commit/3e84fafb3536ed4097d29cf6b691198e4729c3b4))

## 0.12.6 (2026-02-25)

Full Changelog: [v0.12.5...v0.12.6](https://github.com/CaseMark/casedev-python/compare/v0.12.5...v0.12.6)

### Chores

* **internal:** make `test_proxy_environment_variables` more resilient to env ([574334a](https://github.com/CaseMark/casedev-python/commit/574334a89b19baa8fcbb72100c2fc033f2a3c80c))

## 0.12.5 (2026-02-24)

Full Changelog: [v0.12.4...v0.12.5](https://github.com/CaseMark/casedev-python/compare/v0.12.4...v0.12.5)

### Bug Fixes

* prevent duplicate Slack alerts from release-please branches ([5baa9ee](https://github.com/CaseMark/casedev-python/commit/5baa9ee4572bed65b873e4a0e5d7c1e5c0f694f9))

## 0.12.4 (2026-02-24)

Full Changelog: [v0.12.3...v0.12.4](https://github.com/CaseMark/casedev-python/compare/v0.12.3...v0.12.4)

### Chores

* **internal:** make `test_proxy_environment_variables` more resilient ([926dcd4](https://github.com/CaseMark/casedev-python/commit/926dcd48c22e1cf94f3894ed365df6898cb27c59))

## 0.12.3 (2026-02-24)

Full Changelog: [v0.12.2...v0.12.3](https://github.com/CaseMark/casedev-python/compare/v0.12.2...v0.12.3)

### Chores

* **internal:** add request options to SSE classes ([c06aa38](https://github.com/CaseMark/casedev-python/commit/c06aa386cdaa7d2aa51eaa088525c61e959844c4))

## 0.12.2 (2026-02-23)

Full Changelog: [v0.12.1...v0.12.2](https://github.com/CaseMark/casedev-python/compare/v0.12.1...v0.12.2)

### Bug Fixes

* only alert on CI failure for PRs targeting main ([7ad6c4b](https://github.com/CaseMark/casedev-python/commit/7ad6c4b62772ab94d3ca060d27f587eb7e5f8672))
* only alert Slack on CI failure for main branch ([0941a51](https://github.com/CaseMark/casedev-python/commit/0941a5150ba78f3661915378cfd10f7d2dd059b4))

## 0.12.1 (2026-02-23)

Full Changelog: [v0.12.0...v0.12.1](https://github.com/CaseMark/casedev-python/compare/v0.12.0...v0.12.1)

### Chores

* replace PR open Slack alert with CI failure alert ([ddb4311](https://github.com/CaseMark/casedev-python/commit/ddb4311f3e9dbd837e147278e74360c53edfc39f))

## 0.12.0 (2026-02-21)

Full Changelog: [v0.11.2...v0.12.0](https://github.com/CaseMark/casedev-python/compare/v0.11.2...v0.12.0)

### Features

* **api:** api update ([9e34f8a](https://github.com/CaseMark/casedev-python/commit/9e34f8a5dccba5cdb95c1f95208606a6a4a2f440))
* **api:** api update ([135dc3c](https://github.com/CaseMark/casedev-python/commit/135dc3cd51e46fe958d0065821432194c4879beb))

## 0.11.2 (2026-02-20)

Full Changelog: [v0.11.1...v0.11.2](https://github.com/CaseMark/casedev-python/compare/v0.11.1...v0.11.2)

## 0.11.1 (2026-02-20)

Full Changelog: [v0.11.0...v0.11.1](https://github.com/CaseMark/casedev-python/compare/v0.11.0...v0.11.1)

### Chores

* **internal:** remove mock server code ([85989d2](https://github.com/CaseMark/casedev-python/commit/85989d2beea17ba3b7cd73049f09fa0b40dde021))
* update mock server docs ([398b8ee](https://github.com/CaseMark/casedev-python/commit/398b8ee1872d14c12b605015dac7e234a5f6eb8b))

## 0.11.0 (2026-02-20)

Full Changelog: [v0.10.0...v0.11.0](https://github.com/CaseMark/casedev-python/compare/v0.10.0...v0.11.0)

### Features

* **api:** api update ([77773aa](https://github.com/CaseMark/casedev-python/commit/77773aa58e7a5b7296404f1a0cece53c7cbb4d92))

## 0.10.0 (2026-02-19)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/CaseMark/casedev-python/compare/v0.9.0...v0.10.0)

### Features

* **api:** api update ([23dce42](https://github.com/CaseMark/casedev-python/commit/23dce421ed9fa4590d266fcf26a5b9fb77531a9e))
* **api:** api update ([683b41d](https://github.com/CaseMark/casedev-python/commit/683b41d26df92ecd58f95556eb45b5fe64567b1f))
* **api:** api update ([c001e00](https://github.com/CaseMark/casedev-python/commit/c001e001c708a0b0fc0fb4f5bfba401783883999))

## 0.9.0 (2026-02-14)

Full Changelog: [v0.8.1...v0.9.0](https://github.com/CaseMark/casedev-python/compare/v0.8.1...v0.9.0)

### Features

* **api:** api update ([9cc3c1f](https://github.com/CaseMark/casedev-python/commit/9cc3c1f3f1a1171f707c87c3eb6fad14ee2a8e91))

## 0.8.1 (2026-02-14)

Full Changelog: [v0.8.0...v0.8.1](https://github.com/CaseMark/casedev-python/compare/v0.8.0...v0.8.1)

### Bug Fixes

* resolve CI failures in smoke test integration ([9f166ff](https://github.com/CaseMark/casedev-python/commit/9f166ffdbdbe73ac5092a212070e11350ba3d9ff))


### Styles

* fix ruff isort import formatting in smoke tests ([e80a3f3](https://github.com/CaseMark/casedev-python/commit/e80a3f35b28539a307ccf6be344e862cfb18679e))

## 0.8.0 (2026-02-13)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/CaseMark/casedev-python/compare/v0.7.0...v0.8.0)

### Features

* **api:** api update ([030d193](https://github.com/CaseMark/casedev-python/commit/030d193974713a91146ab6f1318fc940f44ff297))

## 0.7.0 (2026-02-13)

Full Changelog: [v0.6.1...v0.7.0](https://github.com/CaseMark/casedev-python/compare/v0.6.1...v0.7.0)

### Features

* **api:** api update ([e7ffc76](https://github.com/CaseMark/casedev-python/commit/e7ffc76d19f6ef07eb8dede8d5e447ec120e9e9b))
* **api:** api update ([a4f3ec4](https://github.com/CaseMark/casedev-python/commit/a4f3ec4a63d720f1609724986690da1570bb9ad2))
* **api:** api update ([1302637](https://github.com/CaseMark/casedev-python/commit/1302637edebcb3969708cd36ad4b2f55c81d4fae))


### Chores

* format all `api.md` files ([0a14fe4](https://github.com/CaseMark/casedev-python/commit/0a14fe431acd3a9a034d51d15448ed8013ef347e))
* **internal:** fix lint error on Python 3.14 ([949df45](https://github.com/CaseMark/casedev-python/commit/949df458de6bcb8b4f6a12a1ad9128d9b8af4250))

## 0.6.1 (2026-02-10)

Full Changelog: [v0.6.0...v0.6.1](https://github.com/CaseMark/casedev-python/compare/v0.6.0...v0.6.1)

### Chores

* **internal:** bump dependencies ([983f265](https://github.com/CaseMark/casedev-python/commit/983f265316c1ca4fbd5dd414f574abc5a62be27b))

## 0.6.0 (2026-02-10)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/CaseMark/casedev-python/compare/v0.5.0...v0.6.0)

### Features

* **api:** api update ([36cbc0c](https://github.com/CaseMark/casedev-python/commit/36cbc0cf466fd98fcf58b7a40a2b2080ad9b21f3))


### Chores

* update SDK settings ([4f246c4](https://github.com/CaseMark/casedev-python/commit/4f246c445acecc3553791855f9eb9b24a1423c00))

## 0.5.0 (2026-02-06)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/CaseMark/casedev-python/compare/v0.4.0...v0.5.0)

### Features

* **api:** api update ([68cd352](https://github.com/CaseMark/casedev-python/commit/68cd352836fcab271ba9ae1b513b7d94c5d1a7c2))

## 0.4.0 (2026-02-04)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/CaseMark/casedev-python/compare/v0.3.0...v0.4.0)

### Features

* **api:** api update ([d47d2e2](https://github.com/CaseMark/casedev-python/commit/d47d2e22941bbee814a3e7e99bb6ab611786c2b8))
* **api:** api update ([b5968ff](https://github.com/CaseMark/casedev-python/commit/b5968ff3ecf6faaa54dabdb1c369a98dccf16229))
* **api:** api update ([a1bfede](https://github.com/CaseMark/casedev-python/commit/a1bfedec986cfe7f79b569d0841f43befc230633))
* **api:** api update ([a740247](https://github.com/CaseMark/casedev-python/commit/a7402478c5ec609a514d125c3e8be3049fe687d2))

## 0.3.0 (2026-01-31)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/CaseMark/casedev-python/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([9552466](https://github.com/CaseMark/casedev-python/commit/95524660fc8d6bc6b4afbd3e881bf15e7378cfe0))
* **api:** api update ([e3f5b6b](https://github.com/CaseMark/casedev-python/commit/e3f5b6bcc11924a87716cbb6e99d39e0c0603f74))
* **api:** api update ([ab9ad93](https://github.com/CaseMark/casedev-python/commit/ab9ad9365e44ec36f5ba3cb5c47436bcdcba095e))
* **api:** api update ([92d6d3e](https://github.com/CaseMark/casedev-python/commit/92d6d3e780ef1f21b3d5fb1839be1bb1973bdec9))
* **api:** api update ([c1ae1f0](https://github.com/CaseMark/casedev-python/commit/c1ae1f0f67d01c6131cea0a3cdfdd7b62430e57a))
* **client:** add custom JSON encoder for extended type support ([34a252e](https://github.com/CaseMark/casedev-python/commit/34a252ea9464e00bd27f8b12fcb027e283c095bd))

## 0.2.0 (2026-01-24)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/CaseMark/casedev-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([cb57987](https://github.com/CaseMark/casedev-python/commit/cb57987717857d312dd3a6c733eb3d64b40d874a))
* **api:** api update ([6f7ac9f](https://github.com/CaseMark/casedev-python/commit/6f7ac9f96595e35b20e6b7f33af36532a163a9a8))
* **api:** api update ([fea56de](https://github.com/CaseMark/casedev-python/commit/fea56ded1aaf613e112aca7b6a2d6ec0fe2275f3))
* **api:** api update ([237a3cc](https://github.com/CaseMark/casedev-python/commit/237a3cc7fe524e9becf35efb45edbd4e4676db1e))
* **api:** api update ([b56886e](https://github.com/CaseMark/casedev-python/commit/b56886ec5a36b297b6421e9bfa58589471efc0f3))
* **api:** api update ([266e6e0](https://github.com/CaseMark/casedev-python/commit/266e6e03886b8a962e1d233cefb1a4e799689077))
* **api:** api update ([b4fd0e1](https://github.com/CaseMark/casedev-python/commit/b4fd0e192591735cd313c2f8a2ebd4bb585f9a22))
* **api:** api update ([eff5344](https://github.com/CaseMark/casedev-python/commit/eff53445012586d2e33b0617108d15671a6557de))
* **api:** api update ([c39c859](https://github.com/CaseMark/casedev-python/commit/c39c859876d97500712f1dd6f071cf440b61077b))
* **api:** api update ([072926b](https://github.com/CaseMark/casedev-python/commit/072926ba2fc867216cd8a87dad7f4cb5ace4d851))
* **api:** api update ([4477cc4](https://github.com/CaseMark/casedev-python/commit/4477cc432fd5f46f4a4e9776b915bfa9e458fab4))
* **api:** api update ([06a0f2a](https://github.com/CaseMark/casedev-python/commit/06a0f2a30aecf7913bf0b34367348c83c6483d72))
* **api:** api update ([f662b55](https://github.com/CaseMark/casedev-python/commit/f662b5554f1df2769e0909083fa8f56ad47f113b))
* **api:** api update ([8ac179e](https://github.com/CaseMark/casedev-python/commit/8ac179eda3b6e3e94439777d9528e2fd32e4d84b))
* **api:** api update ([8289fd5](https://github.com/CaseMark/casedev-python/commit/8289fd58159c05d5a565de08f3dd08814df0890b))
* **client:** add support for binary request streaming ([7e76b57](https://github.com/CaseMark/casedev-python/commit/7e76b572106469ad4f4b910e0b45cce5ee68fcae))


### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([1176765](https://github.com/CaseMark/casedev-python/commit/117676502d91fa5f20073851bf074f508ade4e40))
* use async_to_httpx_files in patch method ([77d15e3](https://github.com/CaseMark/casedev-python/commit/77d15e35c394f535ecbe98d2f5b7c2cd4f151489))


### Chores

* add missing docstrings ([ed8538a](https://github.com/CaseMark/casedev-python/commit/ed8538a2830c45222529a3571053a5b3cbca184c))
* **ci:** upgrade `actions/github-script` ([8057dc0](https://github.com/CaseMark/casedev-python/commit/8057dc0a5ef3a91441aac335711c2934323aa87c))
* **internal:** add `--fix` argument to lint script ([d402a1a](https://github.com/CaseMark/casedev-python/commit/d402a1a46693b9c721b7e573ee1ec54584afca37))
* **internal:** add missing files argument to base client ([e45cbc5](https://github.com/CaseMark/casedev-python/commit/e45cbc54372e2d93a6b6ec58e8e546ed6bfad117))
* **internal:** update `actions/checkout` version ([483fb99](https://github.com/CaseMark/casedev-python/commit/483fb99d0c65ce7eba40870dddfa84c7fb86966d))
* speedup initial import ([8185ce9](https://github.com/CaseMark/casedev-python/commit/8185ce9973ce7076ae88aa2dcb7868450f9ea1b5))
* update SDK settings ([498643c](https://github.com/CaseMark/casedev-python/commit/498643c394fa4d9473e76475f025e3a9ab2562d8))


### Refactors

* **internal:** switch from rye to uv ([910f118](https://github.com/CaseMark/casedev-python/commit/910f11868c852a8d33422301ec80036081dcaf5d))

## 0.1.0 (2025-12-08)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/CaseMark/casedev-python/compare/v0.0.1...v0.1.0)

### Features

* **api:** api update ([f016636](https://github.com/CaseMark/casedev-python/commit/f01663617b152a538b7ca668272be3dfcc3b0dc9))
* **api:** api update ([3966424](https://github.com/CaseMark/casedev-python/commit/3966424bf12ae7bd1c389fb18e85ec27fb784b4c))
* **api:** api update ([bdd8f5b](https://github.com/CaseMark/casedev-python/commit/bdd8f5b481346d6354609b4b09ebae8dbd71a9fc))
* **api:** api update ([8d0cbe9](https://github.com/CaseMark/casedev-python/commit/8d0cbe93ef8fb68e4895b064c7a5483b8d50dc2c))
* **api:** api update ([46a5bca](https://github.com/CaseMark/casedev-python/commit/46a5bcab1b018f33c1c45daf3584678fece36f3c))
* **api:** manual updates ([0857a27](https://github.com/CaseMark/casedev-python/commit/0857a27df9330ed223236f22b4c086146c15d1f8))
* **api:** manual updates ([eeb7830](https://github.com/CaseMark/casedev-python/commit/eeb7830cb058b1ef4be3c6edfefa1a33efe16f0e))
* **api:** manual updates ([7c7022f](https://github.com/CaseMark/casedev-python/commit/7c7022f6e7b5603b8e98f75fe102219f789ff3ba))


### Bug Fixes

* ensure streams are always closed ([b30b9ec](https://github.com/CaseMark/casedev-python/commit/b30b9ec808299da7d4bfade2a52b9a5529bf3d9a))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([714ab77](https://github.com/CaseMark/casedev-python/commit/714ab7768f8895da8e0e6c56ceb506dd946d7e76))
* **docs:** use environment variables for authentication in code snippets ([f57c037](https://github.com/CaseMark/casedev-python/commit/f57c037c435e38d740180acdfa155252f610315e))
* update lockfile ([56cba77](https://github.com/CaseMark/casedev-python/commit/56cba77d5c25b33a5464120c58e648a44921b43c))
* update SDK settings ([0fb22b3](https://github.com/CaseMark/casedev-python/commit/0fb22b30b2bf11f50b8c7a23e020c3e51878f817))
